Debugging
---------

The binary :py:mod:`~brille._brille` module can be set to emit status and timing
information which can be useful for debugging and fine-grained profiling
purposes.

Status output is controlled by :py:func:`~brille._brille.emit` and timing output
is controlled by :py:func:`~brille._brille.emit_datetime`.


.. autofunction:: brille._brille.emit

.. autofunction:: brille._brille.emit_datetime
